# PILOT
An open source carPC operating system for Raspberry Pi written using Python 3.

Full documentation is on the way along with a more detailed README, but in the 
meantime feel free to ask questions, contribute, and give contrusctive criticism! 
I'm new to the open source community, & absolutely taking any feedback I can get. 


